@@ -2,8 +2,8 @@
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: yesod-core
 version: 1.4.19
-id: yesod-core-1.4.19-1b35f3e0bc5edf244c8b12abed4fd6c1
-key: yesod_Kg2K77RtKoK6tKZ5OPMGwx
+id: yesod-core-1.4.19-42832ae56c3d48408d8da65a0e354ab2
+key: yesod_AE4Vj62ue3P09EjC5QAKJV
 license: MIT
 maintainer: Michael Snoyman <michael@snoyman.com>
 stability: Stable
@@ -33,9 +33,9 @@ trusted: False
 import-dirs: /usr/lib/ghc-7.10.3/site-local/yesod-core-1.4.19
 library-dirs: /usr/lib/ghc-7.10.3/site-local/yesod-core-1.4.19
 data-dir: /usr/share/arm-linux-ghc-7.10.3/yesod-core-1.4.19
-hs-libraries: HSyesod-core-1.4.19-Kg2K77RtKoK6tKZ5OPMGwx
+hs-libraries: HSyesod-core-1.4.19-AE4Vj62ue3P09EjC5QAKJV
 depends:
-    aeson-0.11.1.0-01f93b6d659087121e16b9df8deda57c
+    aeson-0.11.1.1-0413068b3d94ca1008e286bfe7fa084f
     auto-update-0.1.3-4edf36ce78b71bfaad1ce3737442c65f
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
     blaze-builder-0.4.0.1-3daa45cd3be9618b289586d273c59e36
@@ -46,8 +46,8 @@ depends:
     case-insensitive-1.2.0.5-6669cd7a393ccedc4f66c0a01b6f0e2f
     cereal-0.5.1.0-2c7be146776a4abf674d1ac9e0ccfc13
     clientsession-0.9.1.1-763bfd866302839ae7dcaa53517a3160
-    conduit-1.2.6.3-0e2837c15036cd2e0c379e7f893dd487
-    conduit-extra-1.1.11-c734df1add5fd1001eeb71b770cb5cb3
+    conduit-1.2.6.4-0dfd87f475e845002478c37d3a30df1e
+    conduit-extra-1.1.11-a2feb7bf273f01f86e07dfa0c39c1b6a
     containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
     cookie-0.4.1.6-8a746b417cee9e54ae77a0b2d5e8515e
     data-default-0.5.3-a34fab0e414a3e31b9dccb1774520fca
@@ -58,7 +58,7 @@ depends:
     http-types-0.9-d392878af9c5e1b1993961dc71a9e177
     lifted-base-0.2.3.6-26b5b3c50c56a653ba3c5b8bce492107
     monad-control-1.0.0.5-237b0aabd7893e5e3f4b9224e05c849c
-    monad-logger-0.3.18-cd8d51c949646894888975572eea97f1
+    monad-logger-0.3.18-7704b739a8ba950a4b62906c3ab56228
     mtl-2.2.1-c516313407bc17046965067cb7cbb6a0
     mwc-random-0.13.4.0-5fa3ad33ef5e7f15e9e572967b6dc242
     old-locale-1.0.0.7-5aedb410aa2e5fddd3c57e9b4de1f46a
@@ -69,7 +69,7 @@ depends:
     resourcet-1.1.7.3-3e7ca03abacc332d28328c69bbd74cd4
     safe-0.3.9-b613242f536083d5bb04920ede356aea
     semigroups-0.18.1-4a4dee25d838ab8c8d38a0caa045cf78
-    shakespeare-2.0.7-d65cfe041713246ebadd86a7511ba6cd
+    shakespeare-2.0.7-39cc4f42107716d9e8a539beb0a84dc6
     template-haskell-2.10.0.0-4b92ab565139fd81021b60a162b59eb8
     text-1.2.2.0-2f82ea4adfdd656d9a8840ad2ee17cc0
     time-1.5.0.1-cf94b0d806e26f6c4e356671290061b2
@@ -79,9 +79,9 @@ depends:
     unordered-containers-0.2.7.0-03f1d2fb96e30aca19bb1467e9476c22
     vector-0.11.0.0-711d35c4a6ac1ea2e529dc3ee3328963
     wai-3.2.0-61d8ab991e10dd6c5057d0dabf632d2a
-    wai-extra-3.0.14.1-5f3982898a5be41036c34bae0277136d
+    wai-extra-3.0.14.1-66e8055b51d984feb43fefdbcd17f927
     wai-logger-2.2.4.1-f24597f93ba49a0bbd4e6ed0edc7bef2
-    warp-3.2.3-e779983be81de2d2755ab5db7108dace
+    warp-3.2.3-b193a405602f21fe67837dcb996939ee
     word8-0.1.2-9a296ac80618be494d93f29b398e749d
 haddock-interfaces: /usr/share/doc/haskell-yesod-core/html/yesod-core.haddock
 haddock-html: /usr/share/doc/haskell-yesod-core/html
